# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs     0
%else
%define build_docs     1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define qttarballdir         qtremoteobjects-everywhere-opensource-src-%{qtversion}

# Library names

%define libqtremoteobjects   %mklibname qt%{qtmajor}remoteobjects %{qtmajor}
%define libqtremoteobjects_d %mklibname qt%{qtmajor}remoteobjects -d

Name:           qtremoteobjects5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} RemoteObjects component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5Network) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}

Provides:       qt%{qtmajor}-qtremoteobjects = %{version}-%{release}

%description
Qt%{qtmajor} Remote Objects module provides an easy to use mechanism for
sharing a QObject's API (Properties/Signals/Slots) between processes.

%files
%{_qt5_bindir}/repc
%{_qt5_qml}/QtQml/RemoteObjects/
%{_qt5_qml}/QtRemoteObjects/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtRemoteObjects%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtRemoteObjects%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtremoteobjects.qch
%{_qt5_docdir}/qtremoteobjects/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtremoteobjects}
Summary:        Qt%{qtmajor} RemoteObjects Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtremoteobjects}
Qt%{qtmajor} RemoteObjects Component Library.

%files -n %{libqtremoteobjects}
%{_qt5_libdir}/libQt5RemoteObjects.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtremoteobjects_d}
Summary:        Devel files needed to build apps based on QtRemoteObjects
Group:          Development/KDE and Qt
Requires:       %{libqtremoteobjects} = %{version}
Provides:       libqtremoteobjects5-devel = %{version}
Provides:       libqt5remoteobjects-devel = %{version}
Provides:       qtremoteobjects5-devel = %{version}
Provides:       qt5remoteobjects-devel = %{version}

%description -n %{libqtremoteobjects_d}
Devel files needed to build apps based on Qt RemoteObjects.

%files -n %{libqtremoteobjects_d}
%{_qt5_includedir}/QtRemoteObjects/
%{_qt5_includedir}/QtRepParser/
%{_qt5_libdir}/libQt5RemoteObjects.so
%{_qt5_libdir}/pkgconfig/Qt5RemoteObjects.pc
%{_qt5_libdir}/pkgconfig/Qt5RepParser.pc
%{_qt5_libdir}/cmake/Qt5RemoteObjects/
%{_qt5_libdir}/cmake/Qt5RepParser/
%{_qt5_libdir}/*.prl
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_archdatadir}/mkspecs/features/*.pri
%{_qt5_archdatadir}/mkspecs/features/*.prf
%{_qt5_examplesdir}/remoteobjects/

#------------------------------------------------------------------------------

%prep
%setup -q -n qtremoteobjects-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif


%changelog
* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139635
- New version 5.15.16

* Tue Jan 09 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2029332
- New version 5.15.12

* Sat Dec 03 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1915356
- New version 5.15.7

* Thu Sep 08 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1885959
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1881064
- New version 5.15.5

* Mon Apr 04 2022 umeabot <umeabot> 5.15.2-2.mga9
+ Revision: 1843235
- Mageia 9 Mass Rebuild

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652464
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624916
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589829
- New version 5.15.0

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545494
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484403
- New version 5.14.1

* Mon Sep 09 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438716
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421119
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418156
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384495
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378542
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362287
- New version 5.12.1

* Thu Dec 13 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1340913
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319031
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300720
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245818
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232117
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216511
- New version 5.10.1

* Fri Mar 02 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1206156
- New version 5.9.4

* Wed Dec 27 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1185609
- New version 5.9.3

* Wed Aug 09 2017 daviddavid <daviddavid> 5.9.1-1.mga7
+ Revision: 1139424
- initial package qtremoteobjects5

